import * as codebuild from '@aws-cdk/aws-codebuild';
import * as codepipeline from '@aws-cdk/aws-codepipeline';
import * as events from '@aws-cdk/aws-events';
import { Construct } from 'constructs';
import { DockerCredential } from '../../docker-credentials';
import { Construct as CoreConstruct } from '@aws-cdk/core';
/**
 * Props for the UpdatePipelineAction.
 *
 * @stability stable
 */
export interface UpdatePipelineActionProps {
    /**
     * The CodePipeline artifact that holds the Cloud Assembly.
     *
     * @stability stable
     */
    readonly cloudAssemblyInput: codepipeline.Artifact;
    /**
     * (deprecated) Name of the pipeline stack.
     *
     * @default - none
     * @deprecated - Use `pipelineStackHierarchicalId` instead.
     */
    readonly pipelineStackName?: string;
    /**
     * Hierarchical id of the pipeline stack.
     *
     * @stability stable
     */
    readonly pipelineStackHierarchicalId: string;
    /**
     * Version of CDK CLI to 'npm install'.
     *
     * @default - Latest version
     * @stability stable
     */
    readonly cdkCliVersion?: string;
    /**
     * Name of the CodeBuild project.
     *
     * @default - Automatically generated
     * @stability stable
     */
    readonly projectName?: string;
    /**
     * Whether the build step should run in privileged mode.
     *
     * @default - false
     * @stability stable
     */
    readonly privileged?: boolean;
    /**
     * Docker registries and associated credentials necessary during the pipeline self-update stage.
     *
     * @default []
     * @stability stable
     */
    readonly dockerCredentials?: DockerCredential[];
    /**
     * Custom BuildSpec that is merged with generated one.
     *
     * @default - none
     * @stability stable
     */
    readonly buildSpec?: codebuild.BuildSpec;
}
/**
 * Action to self-mutate the pipeline.
 *
 * Creates a CodeBuild project which will use the CDK CLI
 * to deploy the pipeline stack.
 *
 * You do not need to instantiate this action -- it will automatically
 * be added by the pipeline.
 *
 * @stability stable
 */
export declare class UpdatePipelineAction extends CoreConstruct implements codepipeline.IAction {
    private readonly action;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: UpdatePipelineActionProps);
    /**
     * Exists to implement IAction.
     *
     * @stability stable
     */
    bind(scope: CoreConstruct, stage: codepipeline.IStage, options: codepipeline.ActionBindOptions): codepipeline.ActionConfig;
    /**
     * Exists to implement IAction.
     *
     * @stability stable
     */
    onStateChange(name: string, target?: events.IRuleTarget, options?: events.RuleProps): events.Rule;
    /**
     * Exists to implement IAction.
     *
     * @stability stable
     */
    get actionProperties(): codepipeline.ActionProperties;
}
